#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.shape import Shape
from pycatia.system_interfaces.any_object import AnyObject


class ShapeInstance(Shape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         ShapeInstance
                | 
                | The interface to access a CATIAShapeInstance.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.shape_instance = com_object

    @property
    def inputs_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InputsCount() As long (Read Only)
                | 
                |     Returns the number of Inputs.
                | 
                |     Example:
                |         The following example retrieves in inputsCount the number of Inputs of
                |         hybridShapeInstance:
                | 
                |          inputsCount = hybridShapeInstance.InputsCount

        :return: int
        :rtype: int
        """

        return self.shape_instance.InputsCount

    @property
    def outputs_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OutputsCount() As long (Read Only)
                | 
                |     Returns the number of Outputs.
                | 
                |     Example:
                |         The following example retrieves in outputsCount the number of Outputs
                |         of hybridShapeInstance:
                | 
                |          outputsCount = hybridShapeInstance.OutputsCount

        :return: int
        :rtype: int
        """

        return self.shape_instance.OutputsCount

    @property
    def parameters_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ParametersCount() As long (Read Only)
                | 
                |     Returns the number of Parameters.
                | 
                |     Example:
                |         The following example retrieves in parametersCount the number of
                |         parameters of hybridShapeInstance:
                | 
                |          parametersCount = hybridShapeInstance.ParametersCount

        :return: int
        :rtype: int
        """

        return self.shape_instance.ParametersCount

    def get_input(self, i_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetInput(CATBSTR iName) As AnyObject
                | 
                |     Gets an input of a shape instance by its name.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the input of the shape instance 
                | 
                |     Returns:
                |         The input, if found 
                |     Example:
                |         The following example tests if the input was found:
                | 
                |          Set input = shapeInstance.GetInput("Input1")
                |          If TypeName(input)="Nothing" Then
                |               MsgBox "Input not found"
                |          End If

        :param str i_name:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.shape_instance.GetInput(i_name))

    def get_input_data(self, i_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetInputData(CATBSTR iName) As CATBaseDispatch
                | 
                |     Gets an input of a shape instance by its name. Use this method if you want
                |     to retrieve a Reference.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the input of the shape instance 
                | 
                |     Returns:
                |         The input, if found 
                |     Example:
                |         The following example tests if the input was found:
                | 
                |          Set input = shapeInstance.GetInput("Input1")
                |          If TypeName(input)="Nothing" Then
                |               MsgBox "Input not found"
                |          End If

        :param str i_name:
        :return: AnyObject
        :rtype: AnyObject
        """
        return self.shape_instance.GetInputData(i_name)

    def get_input_data_from_position(self, i_position: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetInputDataFromPosition(long iPosition) As
                | CATBaseDispatch
                | 
                |     Gets an input of a hybrid shape instance from its position. Use this method
                |     if you want to retrieve a Reference.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position 
                | 
                |     Returns:
                |         The input, if found 
                |     Example:
                |         The following example tests if the input was found:
                | 
                |          Set input = hybridShapeInstance.GetInputFromPosition(2)
                |          If TypeName(input)="Nothing" Then
                |               MsgBox "Input not found"
                |          End If

        :param int i_position:
        :return: AnyObject
        :rtype: AnyObject
        """
        return self.shape_instance.GetInputDataFromPosition(i_position)

    def get_input_from_position(self, i_position: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetInputFromPosition(long iPosition) As AnyObject
                | 
                |     Gets an input of a hybrid shape instance from its
                |     position.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position 
                | 
                |     Returns:
                |         The input, if found 
                |     Example:
                |         The following example tests if the input was found:
                | 
                |          Set input = hybridShapeInstance.GetInputFromPosition(2)
                |          If TypeName(input)="Nothing" Then
                |               MsgBox "Input not found"
                |          End If

        :param int i_position:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.shape_instance.GetInputFromPosition(i_position))

    def get_output(self, i_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetOutput(CATBSTR iName) As AnyObject
                | 
                |     Gets a Ouput by its name.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the output of the shape instance 
                | 
                |     Returns:
                |         The output, if found 
                |     Example:
                |         The following example tests if the output was found:
                | 
                |          Set output = shapeInstance.GetOuput("Output1")
                |          If TypeName(output)="Nothing" Then
                |               MsgBox "Output not found"
                |          End If

        :param str i_name:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.shape_instance.GetOutput(i_name))

    def get_output_from_position(self, i_position: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetOutputFromPosition(long iPosition) As AnyObject
                | 
                |     Gets a Ouput from its position.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position 
                | 
                |     Returns:
                |         The output, if found 
                |     Example:
                |         The following example tests if the output was found:
                | 
                |          Set output = shapeInstance.GetOuputFromPosition(2)
                |          If TypeName(output)="Nothing" Then
                |               MsgBox "Output not found"
                |          End If

        :param int i_position:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.shape_instance.GetOutputFromPosition(i_position))

    def get_parameter(self, i_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetParameter(CATBSTR iName) As AnyObject
                | 
                |     Gets a parameter of a shape instance by its name.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the parameter of the shape instance 
                | 
                |     Returns:
                |         The parameter, if found 
                |     Example:
                |         The following example tests if the parameter was
                |         found:
                | 
                |          Set parameter = shapeInstance.GetParameter("Parameter1")
                |          If TypeName(parameter)="Nothing" Then
                |               MsgBox "Parameter not found"
                |          End If

        :param str i_name:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.shape_instance.GetParameter(i_name))

    def get_parameter_from_position(self, i_position: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetParameterFromPosition(long iPosition) As AnyObject
                | 
                |     Gets a parameter of a hybrid shape instance from its
                |     position.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position 
                | 
                |     Returns:
                |         The parameter, if found 
                |     Example:
                |         The following example tests if the parameter was
                |         found:
                | 
                |          Set parameter = hybridShapeInstance.GetParameterFromPosition(2)
                |          If TypeName(input)="Nothing" Then
                |                MsgBox "Parameter not found"
                |          End If

        :param int i_position:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.shape_instance.GetParameterFromPosition(i_position))

    def put_input(self, i_name: str, i_input: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutInput(CATBSTR iName,
                | AnyObject iInput)
                | 
                |     Defines an input of a shape instance.
                | 
                |     Parameters:
                | 
                |         iName
                |             The input name 
                |         iInput
                |             The element wich will be input of the shape
                |             instance
                |             All types of 
                | 
                |         Boundary object are possibly supported. 
                |     Example:
                |         The following example defines the input of a shape instance The input
                |         will be a point and its name will be Input1.
                | 
                |          shapeInstance.PutInput "Input1",point

        :param str i_name:
        :param AnyObject i_input:
        :return: None
        :rtype: None
        """
        return self.shape_instance.PutInput(i_name, i_input.com_object)

    def put_input_data(self, i_name: str, i_input: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutInputData(CATBSTR iName,
                | CATBaseDispatch iInput)
                | 
                |     Defines an input of a shape instance. Use this method if you want to set as
                |     input a Reference.
                | 
                |     Parameters:
                | 
                |         iName
                |             The input name 
                |         iInput
                |             The element wich will be input of the shape
                |             instance
                |             All types of 
                | 
                |         Boundary object are possibly supported. 
                |     Example:
                |         The following example defines the input of a shape instance The input
                |         will be a point and its name will be Input1.
                | 
                |          shapeInstance.PutInput "Input1",point

        :param str i_name:
        :param AnyObject i_input:
        :return: None
        :rtype: None
        """
        return self.shape_instance.PutInputData(i_name, i_input.com_object)

    def __repr__(self):
        return f'ShapeInstance(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.edge_fillet import EdgeFillet


class ConstRadEdgeFillet(EdgeFillet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             PartInterfaces.Fillet
                |                                 PartInterfaces.EdgeFillet
                |                                     ConstRadEdgeFillet
                | 
                | Represents the edge fillet shape with a constant radius.
                | The resulting shape is made up of edge fillets built with a constant
                | radius.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.const_rad_edge_fillet = com_object

    @property
    def objects_to_fillet(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ObjectsToFillet() As References (Read Only)
                | 
                |     Returns the collection of reference elements to be
                |     filleted.
                | 
                |     Example:
                |         The following example returns in elements the reference elements to be
                |         filleted of the constant radius edge fillet
                |         firstCstEdgeFillet:
                | 
                |          Set elements = firstCstEdgeFillet.ObjectsToFillet

        :return: References
        :rtype: References
        """

        return References(self.const_rad_edge_fillet.ObjectsToFillet)

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length (Read Only)
                | 
                |     Returns the edge fillet constant radius.
                | 
                |     Example:
                |         The following example returns in radius the radius of the constant
                |         radius edge fillet firstCstEdgeFillet:
                | 
                |          Set radius = firstCstEdgeFillet.Radius

        :return: Length
        :rtype: Length
        """

        return Length(self.const_rad_edge_fillet.Radius)

    def add_object_to_fillet(self, i_object_to_fillet: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddObjectToFillet(Reference iObjectToFillet)
                | 
                |     Adds a new sub-element to be filleted. This sub-element is usually an
                |     edge.
                | 
                |     Parameters:
                | 
                |         iObjectToFillet
                |             The sub-element to be filleted
                |             The following 
                | 
                |         Boundary object is supported: TriDimFeatEdge. 
                | 
                | Example:
                |     The following example adds a new geometrical element element to be filleted
                |     by the constant radius edge fillet firstCstEdgeFillet:
                | 
                |      firstCstEdgeFillet.AddObjectToFillet(element)

        :param Reference i_object_to_fillet:
        :return: None
        :rtype: None
        """
        return self.const_rad_edge_fillet.AddObjectToFillet(i_object_to_fillet.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_object_to_fillet'
        # # vba_code = """
        # # Public Function add_object_to_fillet(const_rad_edge_fillet)
        # #     Dim iObjectToFillet (2)
        # #     const_rad_edge_fillet.AddObjectToFillet iObjectToFillet
        # #     add_object_to_fillet = iObjectToFillet
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_object_to_fillet(self, i_object_to_withdraw: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawObjectToFillet(Reference iObjectToWithdraw)
                | 
                |     Withdraws a sub-element from those to be filleted. This sub-element is
                |     usually an edge.
                | 
                |     Parameters:
                | 
                |         iObjectToWithdraw
                |             The sub-element to withdraw
                |             The following 
                | 
                |         Boundary object is supported: TriDimFeatEdge. 
                | 
                | Example:
                |     The following example withdraws the geometrical element element from those
                |     to be filleted by the constant radius edge fillet
                |     firstCstEdgeFillet:
                | 
                |      firstCstEdgeFillet.WithdrawObjectToFillet(element)

        :param Reference i_object_to_withdraw:
        :return: None
        :rtype: None
        """
        return self.const_rad_edge_fillet.WithdrawObjectToFillet(i_object_to_withdraw.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_object_to_fillet'
        # # vba_code = """
        # # Public Function withdraw_object_to_fillet(const_rad_edge_fillet)
        # #     Dim iObjectToWithdraw (2)
        # #     const_rad_edge_fillet.WithdrawObjectToFillet iObjectToWithdraw
        # #     withdraw_object_to_fillet = iObjectToWithdraw
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ConstRadEdgeFillet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SendToService(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SendToService
                | 
                | This interface allows to use 'Send To' functionalities through an
                | API.
                | Example: Set Send=CATIA.CreateSendTo()
                | This interface requires the installation of CATIA - PPR xPDM Gateway 1 Product
                | (PX1) or the installation of the CATIA-SmarTeam plugin. In case one of these
                | products is not granted, the first invocation to one of CATIASendToService
                | methods will fail.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.send_to_service = com_object

    def add_file(self, i_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFile(CATBSTR iPath)
                | 
                |     Adds a file to the list of the files 'to be copied'. This method verifies
                |     that the given input file is valid (exists and is not a directory), it
                |     recursively adds pointed files.
                | 
                |     Parameters:
                | 
                |         iPath
                |             : The path of the file to be added to the list of the 'to be copied' files. 
                |         Example:
                |             Send.AddFile(iPath)

        :param str i_path:
        :return: None
        :rtype: None
        """
        return self.send_to_service.AddFile(i_path)

    def get_last_send_to_method_error(self, o_error_param: str, o_error_code: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetLastSendToMethodError(CATBSTR oErrorParam,
                | long oErrorCode)
                | 
                |     Retreives the diagnosis related to the last call to SendToService
                |     interface.
                | 
                |     Parameters:
                | 
                |         oErrorParam
                |             A parameter string given together with the error code.
                |             
                |         oErrorCode
                |             The last executed method error code:
                |             code diagnosisoErrorParam value
                |             0 action successfully performed :-)
                |             1 PX1 license not granted 
                |             2 internal error 
                |             5 file already in the list file name
                |             6 file is not in the list file name
                |             7 empty file list 
                |             8 missing target directory 
                |             9 no common root directory 
                |             10 file does not exist file name
                |             11 input is a directory directory name
                |             12 directory check failed directory name
                |             13 invalid file name given name
                |             14 file has no read permission given name
                |             36 allocation failed :-( 

        :param str o_error_param:
        :param int o_error_code:
        :return: None
        :rtype: None
        """
        return self.send_to_service.GetLastSendToMethodError(o_error_param, o_error_code)

    def get_list_of_dependant_file(self, o_dependant: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetListOfDependantFile(CATSafeArrayVariant oDependant)
                | 
                |     Retrieves the complete list of the files recursively pointed by the file given in argument to 
                |     SetInitialFile method. 
                |     Notice : in case AddFile has also been invoked, the files recursively pointed by the added file 
                |     also are retrieved.
                | 
                |     Parameters:
                | 
                |         oDependant
                |             : The table of dependant files. 
                |         Example:
                |             Send.GetListOfDependantFile(oDependant)

        :param tuple o_dependant:
        :return: None
        :rtype: None
        """
        return self.send_to_service.GetListOfDependantFile(o_dependant)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_dependant_file'
        # # vba_code = """
        # # Public Function get_list_of_dependant_file(send_to_service)
        # #     Dim oDependant (2)
        # #     send_to_service.GetListOfDependantFile oDependant
        # #     get_list_of_dependant_file = oDependant
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_to_be_copied_files(self, o_will_be_copied: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetListOfToBeCopiedFiles(CATSafeArrayVariant
                | oWillBeCopied)
                | 
                |     Retreives the complete list of the files that will be copied. This list
                |     matches the list of dependant files, but without the files for which RemoveFile
                |     has been invoked.
                | 
                |     Parameters:
                | 
                |         oWillBeCopied
                |             : The table of the files that will be copied. 
                |         Example:
                |             Send.GetListOfToBeCopiedFiles(oWillBeCopied)

        :param tuple o_will_be_copied:
        :return: None
        :rtype: None
        """
        return self.send_to_service.GetListOfToBeCopiedFiles(o_will_be_copied)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_to_be_copied_files'
        # # vba_code = """
        # # Public Function get_list_of_to_be_copied_files(send_to_service)
        # #     Dim oWillBeCopied (2)
        # #     send_to_service.GetListOfToBeCopiedFiles oWillBeCopied
        # #     get_list_of_to_be_copied_files = oWillBeCopied
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def keep_directory(self, i_keep: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub KeepDirectory(boolean iKeep)
                | 
                |     Controls the directory tree structure in the target
                |     directory.
                | 
                |     Parameters:
                | 
                |         iKeep
                |             =1: to preserve the relative tree structure of the
                |             files.
                |             This option will be effective only if there is a common root
                |             directory for all files. 
                |         iKeep
                |             =0: to copy the files directly in the destination directory
                |             
                |         Example:
                |             Send.KeepDirectory(ikeep)

        :param bool i_keep:
        :return: None
        :rtype: None
        """
        return self.send_to_service.KeepDirectory(i_keep)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'keep_directory'
        # # vba_code = """
        # # Public Function keep_directory(send_to_service)
        # #     Dim iKeep (2)
        # #     send_to_service.KeepDirectory iKeep
        # #     keep_directory = iKeep
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_file(self, i_file: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveFile(CATBSTR iFile)
                | 
                |     Removes a file from the list of the files that will be
                |     copied.
                | 
                |     Parameters:
                | 
                |         iFile
                |             : The File (With extension) to be removed from the list of the 'to be copied' files. 
                |         Example:
                |             Send.RemoveFile(iFile)

        :param str i_file:
        :return: None
        :rtype: None
        """
        return self.send_to_service.RemoveFile(i_file)

    def run(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Run()
                | 
                |     Executes the copy action, according to previously set files and
                |     options.
                |     A "report.txt" report file is generated in the specified destination
                |     directory.

        :return: None
        :rtype: None
        """
        return self.send_to_service.Run()

    def set_directory_file(self, i_directory: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDirectoryFile(CATBSTR iDirectory)
                | 
                |     Positions the destination directory. This method verifies that the given
                |     directory exists. Be careful, if SetDirectoryOneFile method has been previously
                |     called, its action is overriden by this SetDirectoryFile
                |     call.
                | 
                |     Parameters:
                | 
                |         iDirectory
                |             : The destination directory where the files will be copied. 
                |         Example:
                |             Send.SetDirectoryFile(iDirectory)

        :param str i_directory:
        :return: None
        :rtype: None
        """
        return self.send_to_service.SetDirectoryFile(i_directory)

    def set_directory_one_file(self, i_file: str, i_directory: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDirectoryOneFile(CATBSTR iFile,
                | CATBSTR iDirectory)
                | 
                |     Allows positioning the destination directory for one given file to be
                |     copied. The file will be copied in the specified target directory. Be careful
                |     that using this method implies that the 'KeepDirectory' variable will be
                |     automatically set to 0.
                | 
                |     Parameters:
                | 
                |         iFile
                |             : The name (Name With extension) of the given file. 
                |         iDirectory
                |             : The directory where this file will be copied. 
                |         Example:
                |             Send.SetDirectoryOneFile(iFile, iDirectory)

        :param str i_file:
        :param str i_directory:
        :return: None
        :rtype: None
        """
        return self.send_to_service.SetDirectoryOneFile(i_file, i_directory)

    def set_initial_file(self, i_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetInitialFile(CATBSTR iPath)
                | 
                |     Sets the initial file to be copied. This method verifies that the given
                |     input file is valid (exists and is not a directory)
                |     It generates a complete list of the recursively dependent files to be
                |     copied. 
                | Example:
                |     This example positions the file of path ipath in the list of 'to be copied'
                |     files. All its dependant files will also be added in the list of 'to be copied'
                |     files.
                | 
                |     Parameters:
                | 
                |         iPath
                |             : Full path of the file to be copied.
                | 
                |              Send.SetInitialFile(iPath)

        :param str i_path:
        :return: None
        :rtype: None
        """
        return self.send_to_service.SetInitialFile(i_path)

    def set_rename_file(self, i_oldname: str, i_new_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRenameFile(CATBSTR iOldname,
                | CATBSTR iNewName)
                | 
                |     Renames one file to be copied. The new name may not have invalid
                |     characters
                | 
                |     Parameters:
                | 
                |         iOldname
                |             : The old file name (With extension). 
                |         iNewName
                |             : The new file name (Without extension). 
                |         Example:
                |             Send.SetRenameFile(iOldname, iNewName)

        :param str i_oldname:
        :param str i_new_name:
        :return: None
        :rtype: None
        """
        return self.send_to_service.SetRenameFile(i_oldname, i_new_name)

    def __repr__(self):
        return f'SendToService(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.part_interfaces.surface_based_shape import SurfaceBasedShape


class ReplaceFace(SurfaceBasedShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SurfaceBasedShape
                |                             ReplaceFace
                | 
                | Represents the Replace Face operation.
                | It replaces a face or a set of faces obtained by tangency continuity by a
                | replacing element, such as a surface or a face or a skin.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.replace_face = com_object

    @property
    def remove_face(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RemoveFace() As References (Read Only)
                | 
                |     Returns the face to be removed.

        :return: References
        :rtype: References
        """

        return References(self.replace_face.RemoveFace)

    @property
    def splitting_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SplittingSide() As CatSplitSide
                | 
                |     Returns or sets the splitting side . The splitting side is the side of the
                |     body kept after the splitting. A positive side refers to the same orientation
                |     than the splitting element normal vector.

        :return: int
        :rtype: int
        """

        return self.replace_face.SplittingSide

    @splitting_side.setter
    def splitting_side(self, value: int):
        """
        :param int value:
        """

        self.replace_face.SplittingSide = value

    def add_remove_face(self, i_remove_face: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddRemoveFace(Reference iRemoveFace)
                | 
                |     Sets the face to be removed.

        :param Reference i_remove_face:
        :return: None
        :rtype: None
        """
        return self.replace_face.AddRemoveFace(i_remove_face.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_remove_face'
        # # vba_code = """
        # # Public Function add_remove_face(replace_face)
        # #     Dim iRemoveFace (2)
        # #     replace_face.AddRemoveFace iRemoveFace
        # #     add_remove_face = iRemoveFace
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_split_plane(self, i_split_plane: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddSplitPlane(Reference iSplitPlane)
                | 
                |     Sets the replacing element.

        :param Reference i_split_plane:
        :return: None
        :rtype: None
        """
        return self.replace_face.AddSplitPlane(i_split_plane.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_split_plane'
        # # vba_code = """
        # # Public Function add_split_plane(replace_face)
        # #     Dim iSplitPlane (2)
        # #     replace_face.AddSplitPlane iSplitPlane
        # #     add_split_plane = iSplitPlane
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_remove_face(self, i_remove_face: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub DeleteRemoveFace(Reference iRemoveFace)
                | 
                |     Remove the face to be removed.

        :param Reference i_remove_face:
        :return: None
        :rtype: None
        """
        return self.replace_face.DeleteRemoveFace(i_remove_face.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_remove_face'
        # # vba_code = """
        # # Public Function delete_remove_face(replace_face)
        # #     Dim iRemoveFace (2)
        # #     replace_face.DeleteRemoveFace iRemoveFace
        # #     delete_remove_face = iRemoveFace
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ReplaceFace(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.part_interfaces.surface_based_shape import SurfaceBasedShape


class Split(SurfaceBasedShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SurfaceBasedShape
                |                             Split
                | 
                | Represents the split operation.
                | It splits a shape using a splitting element, such as a surface, a face or a
                | plane.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.split = com_object

    @property
    def splitting_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SplittingSide() As CatSplitSide
                | 
                |     Returns or sets the splitting side . The splitting side is the side of the
                |     splitting element kept after the split. A positive side refers to the same
                |     orientation than the splitting element normal vector.
                | 
                |     Example:
                |         The following example returns in sptSide the splitting side of the
                |         split shape mySplit, and then sets it to
                |         catPositiveSide:
                | 
                |          Set sptSide = mySplit.SplittingSide
                |          mySplit.SplittingSide = catPositiveSide

        :return: int
        :rtype: int
        """

        return self.split.SplittingSide

    @splitting_side.setter
    def splitting_side(self, value: int):
        """
        :param int value:
        """

        self.split.SplittingSide = value

    def __repr__(self):
        return f'Split(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.tps_interfaces.annotation_factory import AnnotationFactory
from pycatia.tps_interfaces.annotation_factory_2 import AnnotationFactory2
from pycatia.tps_interfaces.capture_factory import CaptureFactory
from pycatia.tps_interfaces.captures import Captures
from pycatia.tps_interfaces.tps_view import TPSView
from pycatia.tps_interfaces.tps_view_factory import TPSViewFactory
from pycatia.tps_interfaces.annotations import Annotations
from pycatia.tps_interfaces.tps_views import TPSViews

if TYPE_CHECKING:
    from pycatia.mec_mod_interfaces.part import Part


class AnnotationSet(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnnotationSet
                | 
                | Interface for the TPS Set of objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.annotation_set = com_object

    @property
    def active_view(self) -> TPSView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveView() As TPSView
                | 
                |     Gets or Sets Annotation Set ActiveView.
                | 
                |     Parameters:
                | 
                |         oView
                |             Value of CATIATPSView.

        :return: TPSView
        :rtype: TPSView
        """

        return TPSView(self.annotation_set.ActiveView)

    @active_view.setter
    def active_view(self, value: TPSView):
        """
        :param TPSView value:
        """

        self.annotation_set.ActiveView = value

    @property
    def an_empty_annotations_list(self) -> Annotations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnEmptyAnnotationsList() As Annotations (Read
                | Only)
                | 
                |     Retrieves an empty Annotations'Collection.
                | 
                |     Parameters:
                | 
                |         oAnnots
                |             Empty Annotations' Collection.

        :return: Annotations
        :rtype: Annotations
        """

        return Annotations(self.annotation_set.AnEmptyAnnotationsList)

    @property
    def annotation_factory(self) -> AnnotationFactory:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnnotationFactory() As AnnotationFactory (Read
                | Only)
                | 
                |     Obtain the factory to create annotations.
                | 
                |     Parameters:
                | 
                |         oAFact
                |             Annotations' factory.

        :return: AnnotationFactory
        :rtype: AnnotationFactory
        """
        import pycatia.tps_interfaces.annotation_factory
        return pycatia.tps_interfaces.annotation_factory.AnnotationFactory(self.annotation_set.AnnotationFactory)

    @property
    def annotation_factory_2(self) -> AnnotationFactory2:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnnotationFactory2() As AnnotationFactory2 (Read
                | Only)
                | 
                |     Obtain the factory to create annotations.
                | 
                |     Parameters:
                | 
                |         oAFact
                |             Annotations' factory.

        :return: AnnotationFactory2
        :rtype: AnnotationFactory2
        """
        return AnnotationFactory2(self.annotation_set.AnnotationFactory2)

    @property
    def annotation_set_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnnotationSetType() As CatAnnotationSetType (Read
                | Only)
                | 
                |     Get the annotation Set type.
                | 
                |     Parameters:
                | 
                |         oAnnotationSetType
                |             Value of Set Type.

        :return: int
        :rtype: int
        """

        return self.annotation_set.AnnotationSetType

    @property
    def annotations(self) -> Annotations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Annotations() As Annotations (Read Only)
                | 
                |     Retrieves the TPS components of the set.
                | 
                |     Parameters:
                | 
                |         oAnnots
                |             Collection of returned component.

        :return: Annotations
        :rtype: Annotations
        """

        return Annotations(self.annotation_set.Annotations)

    @property
    def capture_factory(self) -> CaptureFactory:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CaptureFactory() As CaptureFactory (Read Only)
                | 
                |     Obtain the factory to create Capture.
                | 
                |     Parameters:
                | 
                |         opiCapFact
                |             Capture factory.

        :return: CaptureFactory
        :rtype: CaptureFactory
        """

        return CaptureFactory(self.annotation_set.CaptureFactory)

    @property
    def captures(self) -> Captures:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Captures() As Captures (Read Only)
                | 
                |     Retrieves all the Captures that belong to the set.
                | 
                |     Parameters:
                | 
                |         oCaptures
                |             Collection of returned Captures.

        :return: Captures
        :rtype: Captures
        """
        return Captures(self.annotation_set.Captures)

    @property
    def kind_of_set(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property KindOfSet() As CATBSTR (Read Only)
                | 
                |     Give the kind of set (Part, Product...).
                | 
                |     Parameters:
                | 
                |         oKindOfSet
                |             It could be : Part Product Product_TP Process_BB Cgr Cgr_TP.

        :return: str
        :rtype: str
        """

        return self.annotation_set.KindOfSet

    @property
    def standard(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Standard() As CATBSTR (Read Only)
                | 
                |     Retrieves the Parent Standard defined at set creation.
                | 
                |     Parameters:
                | 
                |         oStandard
                |             Name of the Parent Standard applied for all TPS in the set. The
                |             Parent Standard is the international standard on which Standard File is based
                |             on. It can only be ISO, ANSI and JIS. (ANSI stands for
                |             ASME).

        :return: str
        :rtype: str
        """

        return self.annotation_set.Standard

    @property
    def switch_on(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SwitchOn() As boolean
                | 
                |     Gets or Sets Annotation Set Visualization.
                | 
                |     Parameters:
                | 
                |         oDisplay
                |             Value of visualisation mode.

        :return: bool
        :rtype: bool
        """

        return self.annotation_set.SwitchOn

    @switch_on.setter
    def switch_on(self, value: bool):
        """
        :param bool value:
        """

        self.annotation_set.SwitchOn = value

    @property
    def tps_view_factory(self) -> TPSViewFactory:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TPSViewFactory() As TPSViewFactory (Read Only)
                | 
                |     Obtain the factory to create TPS Views.
                | 
                |     Parameters:
                | 
                |         oTPSViewFact
                |             TPS Views' factory.

        :return: TPSViewFactory
        :rtype: TPSViewFactory
        """
        return TPSViewFactory(self.annotation_set.TPSViewFactory)

    @property
    def tps_views(self) -> TPSViews:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TPSViews() As TPSViews (Read Only)
                | 
                |     Retrieves all the TPSViews that belong to the set.
                | 
                |     Parameters:
                | 
                |         oViews
                |             Collection of returned views.

        :return: TPSViews
        :rtype: TPSViews
        """

        return TPSViews(self.annotation_set.TPSViews)

    def apply_view_re_use_when_copy_set_to(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyViewReUseWhenCopySetTo()
                | 
                |     Register for next call to either GlobalCopySetTo and like
                |     methods.
                | 
                |     See also:
                |         CATIAAnnotationSet#GlobalCopySetTo or CATIAAnnotationSet, they are
                |         placed in existing Views. This call sets an option valid for the next import
                |         run only; in other words, this option is reset at the end of import. When
                |         activated, this option will not break the import processing; if no View in
                |         target set can receive a candidate FTA entity resulting from the import,
                |         regular handling is carried on

        :return: None
        :rtype: None
        """
        return self.annotation_set.ApplyViewReUseWhenCopySetTo()

    def global_copy_set_to(self, i_destination_part: 'Part') -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GlobalCopySetTo(Part iDestinationPart) As CATBSTR
                | 
                |     Copies the entire or a subpart of a part level Annotation Set into a
                |     destination CATPart
                | 
                |     Parameters:
                | 
                |         iDestinationPart
                |             destination CATPart. 
                |         oMessage
                |             result of datums merge.

        :param Part i_destination_part:
        :return: str
        :rtype: str
        """
        from pycatia.mec_mod_interfaces.part import Part
        return self.annotation_set.GlobalCopySetTo(i_destination_part.com_object)

    def global_copy_set_to_with_transformation(self, i_destination_part: 'Part', i_transfo: tuple) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GlobalCopySetToWithTransformation(Part
                | iDestinationPart,
                | CATSafeArrayVariant iTransfo) As CATBSTR
                | 
                |     Copies the entire Annotation Set into a destination
                |     CATPart
                | 
                |     Parameters:
                | 
                |         iDestinationPart
                |             destination CATPart. 
                |         iTransfo
                |             Optional argument. Transformation matrix to apply to FTA features
                |             during copy. The transformation is also used for retrieving in the destination
                |             CATPart the geometrical elements the FTA features are rerouted on.
                |             Transformation matrix is composed by a matrix3x3 and a translation vector:
                |             [[a11 a12 a13 a21 a22 a23 a31 a32 a33] [u1 u2 u3]] a11 is in iTransfo(0) a12 is
                |             in iTransfo(1) a13 is in iTransfo(2) a21 is in iTransfo(3) a22 is in
                |             iTransfo(4) a23 is in iTransfo(5) a31 is in iTransfo(6) a32 is in iTransfo(7)
                |             a33 is in iTransfo(8) u1 is in iTransfo(9) u2 is in iTransfo(10) u3 is in
                |             iTransfo(11) 
                |         oMessage
                |             result of datums merge.

        :param Part i_destination_part:
        :param tuple i_transfo:
        :return: str
        :rtype: str
        """
        return self.annotation_set.GlobalCopySetToWithTransformation(i_destination_part.com_object, i_transfo)

    def __repr__(self):
        return f'AnnotationSet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.hybrid_shape_interfaces.point import Point
from pycatia.in_interfaces.reference import Reference


class HybridShapePointTangent(Point):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Point
                |                             HybridShapePointTangent
                | 
                | Point Tangent.
                | Role: Allows to access data of the point feature created as follow
                | :
                | The tangent to the curve at this point is colinear to a given
                | direction.
                | Note: The resulting feature can contain several points.
                | 
                | See also:
                |     Length 
                | See also:
                |     Reference 
                | See also:
                |     HybridShapeDirection 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_point_tangent = com_object

    @property
    def curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Curve() As Reference
                | 
                |     Returns or Gets the supporting curve.
                |     Sub-element(s) supported (see Boundary object): Edge.
                | 
                |     Example
                |     :
                |         This example retrieves in oCurve the supporting Curve for the
                |         PointTangent feature.
                | 
                |          Dim oCurve As CATIAReference   
                |          Set oCurve  = PointTangent.Curve

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_tangent.Curve)

    @curve.setter
    def curve(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_point_tangent.Curve = reference_curve.com_object

    @property
    def direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Direction() As HybridShapeDirection
                | 
                |     Returns or Sets the direction.
                | 
                |     Example
                |     :
                |         This example retrieves in oDirection the tangent direction use to
                |         compute on supporting curve the PointTangent feature.
                | 
                |          Dim oDirection As CATIAHybridShapeDirection
                |          Set oDirection  = PointTangent.Direction

        :return: HybridShapeDirection
        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_point_tangent.Direction)

    @direction.setter
    def direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_point_tangent.Direction = direction.com_object

    def __repr__(self):
        return f'HybridShapePointTangent(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.fillet import Fillet


class TritangentFillet(Fillet):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             PartInterfaces.Fillet
                |                                 TritangentFillet
                | 
                | The Tritangent Fillet feature : a fillet is built between 3 faces,
                | 2 faces will be relimited, the third one ("face to remove")
                | will
                | be used for fillet tangency ; this face will disappear within the resulting
                | shape.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tritangent_fillet = com_object

    @property
    def face_to_remove(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FaceToRemove() As Reference
                | 
                |     Returns the face to be removed by the tritangent fillet.
                | 
                |     Returns:
                |         oFaceToRemove The face to be removed by the fillet (@see CATIAReference
                |         for more information)
                | 
                |         Example:
                |             The following example returns in removedFace the face to be removed
                |             of
                |             tritangent fillet firstTritangentFillet:
                | 
                |              Set removedFace = firstTritangentFillet.FaceToRemove

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.tritangent_fillet.FaceToRemove)

    @face_to_remove.setter
    def face_to_remove(self, value: Reference):
        """
        :param Reference value:
        """

        self.tritangent_fillet.FaceToRemove = value

    @property
    def first_face(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstFace() As Reference
                | 
                |     Returns the first face limiting the tritangent fillet.
                | 
                |     Returns:
                |         oFirstFace The limiting face (@see CATIAReference for more
                |         information)
                | 
                |         Example:
                |             The following example returns in face1 the first limiting face
                |             of
                |             tritangent fillet firstTritangentFillet:
                | 
                |              Set face1 = firstTritangentFillet.FirstFace

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.tritangent_fillet.FirstFace)

    @first_face.setter
    def first_face(self, value: Reference):
        """
        :param Reference value:
        """

        self.tritangent_fillet.FirstFace = value

    @property
    def second_face(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondFace() As Reference
                | 
                |     Returns the second face limiting the tritangent fillet.
                | 
                |     Returns:
                |         oSecondFace The limiting face (@see CATIAReference for more
                |         information)
                | 
                |         Example:
                |             The following example returns in face2 the second limiting face
                |             of
                |             tritangent fillet firstTritangentFillet:
                | 
                |              Set face2 = firstTritangentFillet.SecondFace

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.tritangent_fillet.SecondFace)

    @second_face.setter
    def second_face(self, value: Reference):
        """
        :param Reference value:
        """

        self.tritangent_fillet.SecondFace = value

    def __repr__(self):
        return f'TritangentFillet(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeWrapCurve(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeWrapCurve
                | 
                | Represents the hybrid shape wrap curve surface object.
                | Role: To access the data of the hybrid shape wrap curve surface
                | object.
                | 
                | This data includes:
                | 
                |     Two support surfaces, one at each limit of the wrap curve
                |     surface
                |     Two curves, one for each support surface
                |     The curve closing points
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeWrapCurve
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_wrap_curve = com_object

    @property
    def first_curves_constraint(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstCurvesConstraint() As long
                | 
                |     Returns or sets constraint at first curves of the
                |     WrapCurve.
                |     Legal values:
                |     1 = no constraint
                |     2 = Deformed surface will have the same tangency and the same curvature as the original surface
                |         at first curves.
                | 
                | Example:
                |     This example retrieves in FirstCurvesConstraint the constraint at first
                |     curves of the ShpWrapCurve hybrid shape WrapCurve feature.
                | 
                |      Dim FirstCurvesConstraint As long
                |      Set FirstCurvesConstraint = ShpWrapCurve.FirstCurvesConstraint

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_wrap_curve.FirstCurvesConstraint

    @first_curves_constraint.setter
    def first_curves_constraint(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_wrap_curve.FirstCurvesConstraint = value

    @property
    def last_curves_constraint(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LastCurvesConstraint() As long
                | 
                |     Returns or sets constraint at last curves of the
                |     WrapCurve.
                |     Legal values:
                |     1 = no constraint,
                |     2 = Deformed surface will have the same tangency and the the same curvatureas the original
                |         surface at last curves.
                | 
                | Example:
                |     This example retrieves in LastCurvesConstraint the constraint at last
                |     curves of the ShpWrapCurve hybrid shape WrapCurve feature.
                | 
                |      Dim LastCurvesConstraint As long
                |      Set LastCurvesConstraint = ShpWrapCurve.LastCurvesConstraint

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_wrap_curve.LastCurvesConstraint

    @last_curves_constraint.setter
    def last_curves_constraint(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_wrap_curve.LastCurvesConstraint = value

    @property
    def surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Surface() As Reference
                | 
                |     Returns or sets the surface to deform of the WrapCurve.
                |     Sub-element(s) supported (see Boundary object): Face. 
                | 
                | Example:
                |     This example retrieves in SurfaceToDeform the surface to deform of the
                |     ShpWrapCurve hybrid shape WrapCurve feature.
                | 
                |      SurfaceToDeform = ShpWrapCurve.Surface

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_wrap_curve.Surface)

    @surface.setter
    def surface(self, reference_surface: Reference):
        """
        :param Reference reference_surface:
        """

        self.hybrid_shape_wrap_curve.Surface = reference_surface.com_object

    def get_curves(self, i_position: int, o_reference_curve: Reference, o_target_curve: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCurves(long iPosition,
                | Reference oReferenceCurve,
                | Reference oTargetCurve)
                | 
                |     Returns a curve from the WrapCurve.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position of the curves in the list of curves. 
                |         oReferenceCurve
                |             the reference curve. 
                |         oTargetCurve
                |             the target curve.
                |             Legal values: can be egal to Nothing. In this case, the associated
                |             ref curve will be fixed.
                | 
                |             Example:
                |                 This example retrieves in WrapCurveRefCurve the first reference
                |                 curve of the ShpWrapCurve hybrid shape WrapCurve feature and retrieves in
                |                 WrapCurveTargCurve the first target curve of the ShpWrapCurve hybrid shape
                |                 WrapCurve feature.
                | 
                |                  Dim WrapCurveRefCurve As Reference
                |                  Dim WrapCurveTargCurve As Reference
                |                  ShpWrapCurve.GetCurve(2)

        :param int i_position:
        :param Reference o_reference_curve:
        :param Reference o_target_curve:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_wrap_curve.GetCurves(i_position, o_reference_curve.com_object,
                                                      o_target_curve.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_curves'
        # # vba_code = """
        # # Public Function get_curves(hybrid_shape_wrap_curve)
        # #     Dim iPosition (2)
        # #     hybrid_shape_wrap_curve.GetCurves iPosition
        # #     get_curves = iPosition
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_number_of_curves(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNumberOfCurves() As long
                | 
                |     Returns the number of couples of curves of the WrapCurve.
                | 
                |     Returns:
                |         The number of couples of curves
                |         Legal values: positive or null. 
                | 
                | Example:
                |     This example retrieves in NumberOfCurves the number of couples of curves of
                |     the ShpWrapCurve hybrid shape WrapCurve feature.
                | 
                |      NumberOfCurves = ShpWrapCurve.GetNumberOfCurves(2)

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_wrap_curve.GetNumberOfCurves()

    def get_reference_direction(self, o_direction_type: int, o_direction: HybridShapeDirection) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetReferenceDirection(long oDirectionType,
                | HybridShapeDirection oDirection)
                | 
                |     Gets the reference direction projection of the wrap curve
                |     feature.
                | 
                |     Parameters:
                | 
                |         oDirectionType
                |             type of direction.
                |             Legal values: 1 = reference direction is computed, and 2 = user direction. 
                |         oDirection
                |             curve to be added as a direction, if oDirectionType = 2. 
                |         Example:
                |             This example retrieves in RefDirection the reference direction of
                |             the ShpWrapCurve hybrid shape WrapCurve feature and in RefDirectionType the
                |             reference direction of the ShpWrapCurve hybrid shape
                |             WrapCurve
                | 
                |              Dim RefDirectionType As long 
                |              Dim RefDirection As CATIAHybridShapeDirection 
                |              ShpWrapCurve.SetReferenceDirection (RefDirectionType,
                |              RefDirection)

        :param int o_direction_type:
        :param HybridShapeDirection o_direction:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_wrap_curve.GetReferenceDirection(o_direction_type, o_direction.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_reference_direction'
        # # vba_code = """
        # # Public Function get_reference_direction(hybrid_shape_wrap_curve)
        # #     Dim oDirectionType (2)
        # #     hybrid_shape_wrap_curve.GetReferenceDirection oDirectionType
        # #     get_reference_direction = oDirectionType
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_reference_spine(self, o_spine_type: int, o_spine: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetReferenceSpine(long oSpineType,
                | Reference oSpine)
                | 
                |     Returns the reference spine of the wrap curve feature.
                | 
                |     Parameters:
                | 
                |         oSpineType
                |             type of spine.
                |             Legal values: 1 = Reference Spine is equal to the first reference curve, and
                |                           2 = user spine.
                |         oSpine
                |             curve to be added as a spine, if iSpineType = 2. 
                | 
                |     Example:
                |         This example retrieves in RefSpine the reference spine of the
                |         ShpWrapCurve hybrid shape WrapCurve feature and in RefSpineType the reference
                |         spine type.
                | 
                |          Dim RefSpineType As long 
                |          Dim RefSpine As Reference 
                |          ShpWrapCurve.GetReferenceSpine (RefSpineType,
                |          RefSpine)

        :param int o_spine_type:
        :param Reference o_spine:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_wrap_curve.GetReferenceSpine(o_spine_type, o_spine.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_reference_spine'
        # # vba_code = """
        # # Public Function get_reference_spine(hybrid_shape_wrap_curve)
        # #     Dim oSpineType (2)
        # #     hybrid_shape_wrap_curve.GetReferenceSpine oSpineType
        # #     get_reference_spine = oSpineType
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def insert_curves(self, i_position: int, i_reference_curve: Reference, i_target_curve: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertCurves(long iPosition,
                | Reference iReferenceCurve,
                | Reference iTargetCurve)
                | 
                |     Inserts a couple of reference curve and target curve to the wrap
                |     curve.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position of the curves in the list of curves.
                |             Legal values: 0 for the end of the list, or positive and not null.
                |             
                |         iReferenceCurve
                |             the reference curve.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): TriDimFeatEdge and BiDimFeatEdge. 
                |     iTargetCurve
                |         the target curve.
                |         Sub-element(s) supported (see Boundary object): TriDimFeatEdge and
                |         BiDimFeatEdge.
                | 
                | Example:
                |     This example sets the RefCurveForWrapCurve curve and the
                |     TargCurveForWrapCurve curve at the end of the list to the ShpWrapCurve hybrid
                |     shape WrapCurve feature.
                | 
                |      ShpWrapCurve.InsertCurves (0, RefCurveForWrapCurve,
                |      TargCurveForWrapCurve)

        :param int i_position:
        :param Reference i_reference_curve:
        :param Reference i_target_curve:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_wrap_curve.InsertCurves(i_position, i_reference_curve.com_object,
                                                         i_target_curve.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_curves'
        # # vba_code = """
        # # Public Function insert_curves(hybrid_shape_wrap_curve)
        # #     Dim iPosition (2)
        # #     hybrid_shape_wrap_curve.InsertCurves iPosition
        # #     insert_curves = iPosition
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def insert_reference_curve(self, i_position: int, i_reference_curve: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertReferenceCurve(long iPosition,
                | Reference iReferenceCurve)
                | 
                |     Inserts a of reference curve to the wrap curve.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position of the curves in the list of curves.
                |             Legal values: 0 for the end of the list, or positive and not null.
                |             
                |         iReferenceCurve
                |             the reference curve.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): TriDimFeatEdge and BiDimFeatEdge. 
                |     Example:
                |         This example sets the RefCurveForWrapCurve curve at the end of the list
                |         to the ShpWrapCurve hybrid shape WrapCurve feature.
                | 
                |          ShpWrapCurve.InsertCurves (0, RefCurveForWrapCurve)

        :param int i_position:
        :param Reference i_reference_curve:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_wrap_curve.InsertReferenceCurve(i_position, i_reference_curve.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_reference_curve'
        # # vba_code = """
        # # Public Function insert_reference_curve(hybrid_shape_wrap_curve)
        # #     Dim iPosition (2)
        # #     hybrid_shape_wrap_curve.InsertReferenceCurve iPosition
        # #     insert_reference_curve = iPosition
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_curves(self, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveCurves(long iPosition)
                | 
                |     Removes a couple of reference curve and target curve from the
                |     WrapCurve.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position of the curves in the list of curves.
                |             Legal values: positive, not null and lower to numberOfCurves
                |             
                | 
                |     Example:
                |         This example removes the first couple of reference curve and target
                |         curve of the ShpWrapCurve hybrid shape WrapCurve
                |         feature.
                | 
                |          ShpWrapCurve.RemoveCurves (1)

        :param int i_position:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_wrap_curve.RemoveCurves(i_position)

    def set_reference_direction(self, i_direction: HybridShapeDirection) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReferenceDirection(HybridShapeDirection iDirection)
                | 
                |     Sets the reference direction projection to the wrap curve
                |     feature.
                | 
                |     Parameters:
                | 
                |         iDirection
                |             curve to be added as a direction, if iDirectionType = 2. 
                |         Example:
                |             This example sets the RefDirection curve as the reference direction
                |             of the ShpWrapCurve hybrid shape WrapCurve
                |             feature.
                | 
                |              ShpWrapCurve.SetReferenceDirection RefDirection

        :param HybridShapeDirection i_direction:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_wrap_curve.SetReferenceDirection(i_direction.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_reference_direction'
        # # vba_code = """
        # # Public Function set_reference_direction(hybrid_shape_wrap_curve)
        # #     Dim iDirection (2)
        # #     hybrid_shape_wrap_curve.SetReferenceDirection iDirection
        # #     set_reference_direction = iDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_reference_spine(self, i_spine: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReferenceSpine(Reference iSpine)
                | 
                |     Sets the reference spine to the wrap curve feature.
                | 
                |     Parameters:
                | 
                |         iSpine
                |             curve to be added as a spine.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): TriDimFeatEdge, BiDimFeatEdge. 
                | 
                | Example:
                |     This example sets the Curve10 curve as the reference Spine of the
                |     ShpWrapCurve hybrid shape WrapCurve feature.
                | 
                |      ShpWrapCurve.SetReferenceSpine Curve10

        :param Reference i_spine:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_wrap_curve.SetReferenceSpine(i_spine.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_reference_spine'
        # # vba_code = """
        # # Public Function set_reference_spine(hybrid_shape_wrap_curve)
        # #     Dim iSpine (2)
        # #     hybrid_shape_wrap_curve.SetReferenceSpine iSpine
        # #     set_reference_spine = iSpine
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeWrapCurve(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeSpiral(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeSpiral
                | 
                | Represents the hybrid shape Spiral feature object.
                | Role: Allows to access data of the Spiral feature. This data
                | includes:
                | 
                |     type
                |     support
                |     centre point
                |     axis
                |     starting radius
                |     orientation
                |     ending angle
                |     ending radius
                |     revolution
                |     pitch
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_spiral = com_object

    @property
    def axis(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Axis() As HybridShapeDirection
                | 
                |     Reads / Changes the Spiral axis (Reference direction).

        :return: HybridShapeDirection
        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_spiral.Axis)

    @axis.setter
    def axis(self, reference_axis: HybridShapeDirection):
        """
        :param HybridShapeDirection reference_axis:
        """

        self.hybrid_shape_spiral.Axis = reference_axis.com_object

    @property
    def center_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CenterPoint() As Reference
                | 
                |     Reads / Changes the center point of the Spiral.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_spiral.CenterPoint)

    @center_point.setter
    def center_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_spiral.CenterPoint = reference_point.com_object

    @property
    def clockwise_revolution(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ClockwiseRevolution() As boolean
                | 
                |     Reads / Modifies the sense of revolutions .
                |     FALSE means that revolutions are counter-clockwise.
                |     TRUE means that revolutions are clockwise.

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_spiral.ClockwiseRevolution

    @clockwise_revolution.setter
    def clockwise_revolution(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_spiral.ClockwiseRevolution = value

    @property
    def ending_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndingAngle() As Angle
                | 
                |     Reads / Changes the Ending Angle of the Spiral.

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_spiral.EndingAngle)

    @ending_angle.setter
    def ending_angle(self, angle: Angle):
        """
        :param Angle angle:
        """

        self.hybrid_shape_spiral.EndingAngle = angle.com_object

    @property
    def ending_radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndingRadius() As Length
                | 
                |     Reads / Changes the ending radius of the Spiral.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_spiral.EndingRadius)

    @ending_radius.setter
    def ending_radius(self, length: Length):
        """
        :param Length length:
        """

        self.hybrid_shape_spiral.EndingRadius = length.com_object

    @property
    def invert_axis(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InvertAxis() As boolean
                | 
                |     Reads / Modifies the orientation .
                |     FALSE means that there is no invertion (natural
                |     orientation).
                |     TRUE to invert this orientation.

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_spiral.InvertAxis

    @invert_axis.setter
    def invert_axis(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_spiral.InvertAxis = value

    @property
    def pitch(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Pitch() As Length
                | 
                |     Reads / Changes the pitch of the Spiral.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_spiral.Pitch)

    @pitch.setter
    def pitch(self, length: Length):
        """
        :param Length length:
        """

        self.hybrid_shape_spiral.Pitch = length.com_object

    @property
    def revol_number(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RevolNumber() As RealParam
                | 
                |     Reads / Changes the revolution number of the Spiral.

        :return: RealParam
        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_spiral.RevolNumber)

    @revol_number.setter
    def revol_number(self, real_param: RealParam):
        """
        :param RealParam real_param:
        """

        self.hybrid_shape_spiral.RevolNumber = real_param.com_object

    @property
    def starting_radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property StartingRadius() As Length
                | 
                |     Reads / Changes the starting radius of the Spiral.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_spiral.StartingRadius)

    @starting_radius.setter
    def starting_radius(self, length: Length):
        """
        :param Length length:
        """

        self.hybrid_shape_spiral.StartingRadius = length.com_object

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Reads / Changes the spiral plane support.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_spiral.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_spiral.Support = reference_support.com_object

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Type() As long
                | 
                |     Reads / Changes the spiral type.

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_spiral.Type

    @type.setter
    def type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_spiral.Type = value

    def set_angle_pitch_param(self, i_end_angle: float, i_revol_number: float, i_pitch: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAnglePitchParam(double iEndAngle,
                | double iRevolNumber,
                | double iPitch)
                | 
                |     Sets Angle pitch parameter.

        :param float i_end_angle:
        :param float i_revol_number:
        :param float i_pitch:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spiral.SetAnglePitchParam(i_end_angle, i_revol_number, i_pitch)

    def set_angle_radius_param(self, i_end_angle: float, i_revol_number: float, i_end_radius: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAngleRadiusParam(double iEndAngle,
                | double iRevolNumber,
                | double iEndRadius)
                | 
                |     Sets Angle radius parameters.

        :param float i_end_angle:
        :param float i_revol_number:
        :param float i_end_radius:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spiral.SetAngleRadiusParam(i_end_angle, i_revol_number, i_end_radius)

    def set_radius_pitch_param(self, i_end_radius: float, i_pitch: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRadiusPitchParam(double iEndRadius,
                | double iPitch)
                | 
                |     Sets Radius pitch parameter.

        :param float i_end_radius:
        :param float i_pitch:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spiral.SetRadiusPitchParam(i_end_radius, i_pitch)

    def __repr__(self):
        return f'HybridShapeSpiral(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.cat_mat_interfaces.material import Material


class PositionedMaterial(AnyObject):
    """
    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     PositionedMaterial
            |
            | Represents a Positioned Material object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.positioned_material = com_object

    @property
    def application_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplicationMode() As short (Read Only)
                |
                |     Returns the application mode of the material.
                |
                |         Possible mode values are:
                |         0: Material has been applied as a copy on the
                |         geometrical object
                |         1: Material has been applied as a link on the
                |         geometrical object

        :return: int
        :rtype: int
        """

        return self.positioned_material.ApplicationMode

    @property
    def inheritance_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InheritanceMode() As short
                |
                |     Returns or sets the inheritance mode of an applied
                |     material.
                |
                |         Possible inheritance mode values are:
                |         0: The material is propagated towards its children
                |         1: The material is not propagated towards its children
                |         2: The material do not accept material propagated by
                |            its father (forced mode)

        :return: int
        :rtype: int
        """

        return self.positioned_material.InheritanceMode

    @inheritance_mode.setter
    def inheritance_mode(self, value: int):
        """
        :param int value:
        """

        self.positioned_material.InheritanceMode = value

    @property
    def material(self) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Material() As Material (Read Only)
                |
                |     Returns the material object from the current positioned
                |     material.

        :return: Material
        :rtype: Material
        """

        return Material(self.positioned_material.Material)

    def __repr__(self):
        return f'PositionedMaterial(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class ReportGenerationSheetSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         ReportGenerationSheetSettingAtt
                | 
                | The interface to access a
                | CATIAReportGenerationSheetSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.report_generation_sheet_setting_att = com_object

    @property
    def all_checks_report(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AllChecksReport() As short
                | 
                |     Returns or sets the AllChecksReport parameter.
                |     Role:Return or Set the AllChecksReport parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oAllChecksReport
                |             Legal values:
                |             0 : report of only failed checks
                |             1 : report of all checks.

        :return: int
        :rtype: int
        """

        return self.report_generation_sheet_setting_att.AllChecksReport

    @all_checks_report.setter
    def all_checks_report(self, value: int):
        """
        :param int value:
        """

        self.report_generation_sheet_setting_att.AllChecksReport = value

    @property
    def check_report_html(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CheckReportHtml() As short
                | 
                |     Returns or sets the CheckReportHtml parameter.
                |     Role:Return or Set the CheckReportHtml parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oCheckReportHtml
                |             Legal values:
                |             0 : to have check report in Xml
                |             1 : to have check report in Html.

        :return: int
        :rtype: int
        """

        return self.report_generation_sheet_setting_att.CheckReportHtml

    @check_report_html.setter
    def check_report_html(self, value: int):
        """
        :param int value:
        """

        self.report_generation_sheet_setting_att.CheckReportHtml = value

    @property
    def directory_for_input_xsl(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DirectoryForInputXsl() As CATBSTR
                | 
                |     Returns or sets the DirectoryForInputXsl parameter.
                |     Role:Return or Set the DirectoryForInputXsl parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oDirectoryForInputXsl
                |             Directory for the report file with Xml extension.

        :return: str
        :rtype: str
        """

        return self.report_generation_sheet_setting_att.DirectoryForInputXsl

    @directory_for_input_xsl.setter
    def directory_for_input_xsl(self, value: str):
        """
        :param str value:
        """

        self.report_generation_sheet_setting_att.DirectoryForInputXsl = value

    @property
    def report_check_advisor(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReportCheckAdvisor() As short
                | 
                |     Returns or sets the ReportCheckAdvisor parameter.
                |     Role:Return or Set the ReportCheckAdvisor parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oReportCheckAdvisor
                |             Legal values:
                |             0 : not report of check Advisor
                |             1 : report of check Advisor.

        :return: int
        :rtype: int
        """

        return self.report_generation_sheet_setting_att.ReportCheckAdvisor

    @report_check_advisor.setter
    def report_check_advisor(self, value: int):
        """
        :param int value:
        """

        self.report_generation_sheet_setting_att.ReportCheckAdvisor = value

    @property
    def report_check_expert(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReportCheckExpert() As short
                | 
                |     Returns or sets the ReportCheckExpert parameter.
                |     Role:Return or Set the ReportCheckExpert parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oReportCheckExpert
                |             Legal values:
                |             0 : not report of check Advisor
                |             1 : report of check Advisor.

        :return: int
        :rtype: int
        """

        return self.report_generation_sheet_setting_att.ReportCheckExpert

    @report_check_expert.setter
    def report_check_expert(self, value: int):
        """
        :param int value:
        """

        self.report_generation_sheet_setting_att.ReportCheckExpert = value

    @property
    def report_html_in_catia_session(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReportHtmlInCatiaSession() As short
                | 
                |     Returns or sets the ReportHtmlInCatiaSession parameter.
                |     Role:Return or Set the ReportHtmlInCatiaSession parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oReportHtmlInCatiaSession
                |             Legal values:
                |             0 : report Html outside CATIA session
                |             1 : report Html in CATIA session.

        :return: int
        :rtype: int
        """

        return self.report_generation_sheet_setting_att.ReportHtmlInCatiaSession

    @report_html_in_catia_session.setter
    def report_html_in_catia_session(self, value: int):
        """
        :param int value:
        """

        self.report_generation_sheet_setting_att.ReportHtmlInCatiaSession = value

    @property
    def report_objects_information(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReportObjectsInformation() As short
                | 
                |     Returns or sets the ReportObjectsInformation parameter.
                |     Role:Return or Set the ReportObjectsInformation parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oReportObjectsInformation
                |             Legal values:
                |             0 : not report objects information
                |             1 : report objects information.

        :return: int
        :rtype: int
        """

        return self.report_generation_sheet_setting_att.ReportObjectsInformation

    @report_objects_information.setter
    def report_objects_information(self, value: int):
        """
        :param int value:
        """

        self.report_generation_sheet_setting_att.ReportObjectsInformation = value

    @property
    def report_output_directory(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReportOutputDirectory() As CATBSTR
                | 
                |     Returns or sets the ReportOutputDirectory parameter.
                |     Role:Return or Set the ReportOutputDirectory parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oReportOutputDirectory
                |             The output directory for report of checks expert and checks
                |             advisor.

        :return: str
        :rtype: str
        """

        return self.report_generation_sheet_setting_att.ReportOutputDirectory

    @report_output_directory.setter
    def report_output_directory(self, value: str):
        """
        :param str value:
        """

        self.report_generation_sheet_setting_att.ReportOutputDirectory = value

    @property
    def report_parameters_information(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReportParametersInformation() As short
                | 
                |     Returns or sets the ReportParametersInformation parameter.
                |     Role:Return or Set the ReportParametersInformation parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oReportParametersInformation
                |             Legal values:
                |             0 : not check Advisor parameter information
                |             1 : check Advisor parameter information.

        :return: int
        :rtype: int
        """

        return self.report_generation_sheet_setting_att.ReportParametersInformation

    @report_parameters_information.setter
    def report_parameters_information(self, value: int):
        """
        :param int value:
        """

        self.report_generation_sheet_setting_att.ReportParametersInformation = value

    @property
    def report_passed_objects(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReportPassedObjects() As short
                | 
                |     Returns or sets the ReportPassedObjects parameter.
                |     Role:Return or Set the ReportPassedObjects parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oReportPassedObjects
                |             Legal values:
                |             0 : not report passed objects
                |             1 : report passed objects.

        :return: int
        :rtype: int
        """

        return self.report_generation_sheet_setting_att.ReportPassedObjects

    @report_passed_objects.setter
    def report_passed_objects(self, value: int):
        """
        :param int value:
        """

        self.report_generation_sheet_setting_att.ReportPassedObjects = value

    def get_all_checks_report_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetAllChecksReportInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AllChecksReport
                |     parameter.
                |     Role:Retrieves the state of the AllChecksReport parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetAllChecksReportInfo(io_admin_level, io_locked)

    def get_check_report_html_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetCheckReportHtmlInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CheckReportHtml
                |     parameter.
                |     Role:Retrieves the state of the CheckReportHtml parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetCheckReportHtmlInfo(io_admin_level, io_locked)

    def get_directory_for_input_xsl_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDirectoryForInputXslInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DirectoryForInputXsl
                |     parameter.
                |     Role:Retrieves the state of the DirectoryForInputXsl parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetDirectoryForInputXslInfo(io_admin_level, io_locked)

    def get_report_check_advisor_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReportCheckAdvisorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ReportCheckAdvisor
                |     parameter.
                |     Role:Retrieves the state of the ReportCheckAdvisor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetReportCheckAdvisorInfo(io_admin_level, io_locked)

    def get_report_check_expert_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReportCheckExpertInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ReportCheckExpert
                |     parameter.
                |     Role:Retrieves the state of the ReportCheckExpert parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetReportCheckExpertInfo(io_admin_level, io_locked)

    def get_report_html_in_catia_session_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReportHtmlInCatiaSessionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ReportHtmlInCatiaSession
                |     parameter.
                |     Role:Retrieves the state of the ReportHtmlInCatiaSession parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetReportHtmlInCatiaSessionInfo(io_admin_level, io_locked)

    def get_report_objects_information_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReportObjectsInformationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ReportObjectsInformation
                |     parameter.
                |     Role:Retrieves the state of the ReportObjectsInformation parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetReportObjectsInformationInfo(io_admin_level, io_locked)

    def get_report_output_directory_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReportOutputDirectoryInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ReportOutputDirectory
                |     parameter.
                |     Role:Retrieves the state of the ReportOutputDirectory parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetReportOutputDirectoryInfo(io_admin_level, io_locked)

    def get_report_parameters_information_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReportParametersInformationInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ReportParametersInformation
                |     parameter.
                |     Role:Retrieves the state of the ReportParametersInformation parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetReportParametersInformationInfo(io_admin_level, io_locked)

    def get_report_passed_objects_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReportPassedObjectsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ReportPassedObjects
                |     parameter.
                |     Role:Retrieves the state of the ReportPassedObjects parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.report_generation_sheet_setting_att.GetReportPassedObjectsInfo(io_admin_level, io_locked)

    def set_all_checks_report_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAllChecksReportLock(boolean iLocked)
                | 
                |     Locks or unlocks the AllChecksReport parameter.
                |     Role:Locks or unlocks the AllChecksReport parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetAllChecksReportLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_all_checks_report_lock'
        # # vba_code = """
        # # Public Function set_all_checks_report_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetAllChecksReportLock iLocked
        # #     set_all_checks_report_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_check_report_html_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetCheckReportHtmlLock(boolean iLocked)
                | 
                |     Locks or unlocks the CheckReportHtml parameter.
                |     Role:Locks or unlocks the CheckReportHtml parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetCheckReportHtmlLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_check_report_html_lock'
        # # vba_code = """
        # # Public Function set_check_report_html_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetCheckReportHtmlLock iLocked
        # #     set_check_report_html_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_directory_for_input_xsl_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDirectoryForInputXslLock(boolean iLocked)
                | 
                |     Locks or unlocks the DirectoryForInputXsl parameter.
                |     Role:Locks or unlocks the DirectoryForInputXsl parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetDirectoryForInputXslLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_directory_for_input_xsl_lock'
        # # vba_code = """
        # # Public Function set_directory_for_input_xsl_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetDirectoryForInputXslLock iLocked
        # #     set_directory_for_input_xsl_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_report_check_advisor_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReportCheckAdvisorLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReportCheckAdvisor parameter.
                |     Role:Locks or unlocks the ReportCheckAdvisor parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetReportCheckAdvisorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_report_check_advisor_lock'
        # # vba_code = """
        # # Public Function set_report_check_advisor_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetReportCheckAdvisorLock iLocked
        # #     set_report_check_advisor_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_report_check_expert_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReportCheckExpertLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReportCheckExpert parameter.
                |     Role:Locks or unlocks the ReportCheckExpert parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetReportCheckExpertLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_report_check_expert_lock'
        # # vba_code = """
        # # Public Function set_report_check_expert_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetReportCheckExpertLock iLocked
        # #     set_report_check_expert_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_report_html_in_catia_session_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReportHtmlInCatiaSessionLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReportHtmlInCatiaSession parameter.
                |     Role:Locks or unlocks the ReportHtmlInCatiaSession parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetReportHtmlInCatiaSessionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_report_html_in_catia_session_lock'
        # # vba_code = """
        # # Public Function set_report_html_in_catia_session_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetReportHtmlInCatiaSessionLock iLocked
        # #     set_report_html_in_catia_session_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_report_objects_information_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReportObjectsInformationLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReportObjectsInformation parameter.
                |     Role:Locks or unlocks the ReportObjectsInformation parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetReportObjectsInformationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_report_objects_information_lock'
        # # vba_code = """
        # # Public Function set_report_objects_information_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetReportObjectsInformationLock iLocked
        # #     set_report_objects_information_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_report_output_directory_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReportOutputDirectoryLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReportOutputDirectory parameter.
                |     Role:Locks or unlocks the ReportOutputDirectory parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetReportOutputDirectoryLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_report_output_directory_lock'
        # # vba_code = """
        # # Public Function set_report_output_directory_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetReportOutputDirectoryLock iLocked
        # #     set_report_output_directory_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_report_parameters_information_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReportParametersInformationLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReportParametersInformation
                |     parameter.
                |     Role:Locks or unlocks the ReportParametersInformation parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetReportParametersInformationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_report_parameters_information_lock'
        # # vba_code = """
        # # Public Function set_report_parameters_information_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetReportParametersInformationLock iLocked
        # #     set_report_parameters_information_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_report_passed_objects_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReportPassedObjectsLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReportPassedObjects parameter.
                |     Role:Locks or unlocks the ReportPassedObjects parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.report_generation_sheet_setting_att.SetReportPassedObjectsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_report_passed_objects_lock'
        # # vba_code = """
        # # Public Function set_report_passed_objects_lock(report_generation_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     report_generation_sheet_setting_att.SetReportPassedObjectsLock iLocked
        # #     set_report_passed_objects_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ReportGenerationSheetSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
from typing import Iterator
from typing import TYPE_CHECKING

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.in_interfaces.document import Document


class Products(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Products
                |
                | The collection of the Product objects contained in a given Product object of a
                | ProductDocument object.
                | A Product object can aggregate one or zero Products
                | collection.

    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Product)
        self.products = com_object

    def add_component(self, i_reference_product: Product) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddComponent(Product iReferenceProduct) As Product
                | 
                |     Creates a component and adds it to the Products collection. A component is
                |     a Product object created from another Product object used as
                |     reference.
                |
                |     Parameters:
                |
                |         iReferenceProduct
                |             The product used as reference
                | 
                |     Example:
                |
                |           The following example creates the SpareWheel component
                |           from
                |          the reference product FrontRightWheel and adds the
                |          component
                |          to the ToolKits collection.
                |
                | 
                |          Dim SpareWheel As Product
                |          Set SpareWheel = ToolKits.AddComponent(FrontRightWheel)

        :param Product i_reference_product:
        :return: Product
        :rtype: Product
        """
        return Product(self.products.AddComponent(i_reference_product.com_object))

    def add_components_from_files(self, i_files_list: tuple, i_method: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub AddComponentsFromFiles(CATSafeArrayVariant iFilesList,
                | CATBSTR iMethod)
                | 
                |     Creates a component for each file. The components are added to the Products
                |     collection.
                |
                |     Parameters:
                |
                |         iFilesList
                |             The paths of the files used to retrieve the reference or the shape
                |             of th component
                |         iMethod
                |             A string describing the expected type of the files

        :param tuple i_files_list:
        :param str i_method:
        :return: None
        :rtype: None
        """
        return self.products.AddComponentsFromFiles(i_files_list, i_method)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_components_from_files'
        # # vba_code = """
        # # Public Function add_components_from_files(products)
        # #     Dim iFilesList (2)
        # #     products.AddComponentsFromFiles iFilesList
        # #     add_components_from_files = iFilesList
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_external_component(self, i_product_document: 'Document') -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddExternalComponent(Document iProductDocument) As
                | Product
                | 
                |     Creates a component from the root product of another ProductDocument
                |     object. This root product is used as a reference to create the component. The
                |     component is added to the Products collection.
                |
                |     Parameters:
                |
                |         iProductDocument
                |             The product document whose root object is to be used as reference
                |             to create the component
                | 
                |     Example:
                |
                |           The following example creates the GearBox component
                |           by
                |          referencing the GearBoxDocument and adds it
                |          to the PowerTrains collection.
                |
                | 
                |          Dim GearBox As Product
                |          Set GearBox = PowerTrains.AddExternalComponent(GearBoxDocument)

        :param Document i_product_document:
        :return: Product
        :rtype: Product
        """
        return Product(self.products.AddExternalComponent(i_product_document.com_object))

    def add_new_component(self, i_documen_type: str, i_part_number: str) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddNewComponent(CATBSTR iDocumenType,
                | CATBSTR iPartNumber) As Product
                | 
                |     Creates a component from the root product of a new ProductDocument object.
                |     This root product is used as a reference to create the component. The component
                |     is added to the Products collection.
                |
                |     Parameters:
                |
                |         iProductDocument
                |             The product document whose root object is to be used as reference
                |             to create the component
                | 
                |     Example:
                |
                |           The following example creates the GearBox component
                |           by
                |          referencing the GearBoxDocument and adds it
                |          to the PowerTrains collection.
                |
                | 
                |          Dim GearBox As Product
                |          Set GearBox = PowerTrains.AddNewComponent(GearBoxDocument, "A120-253X-7")

        :param str i_documen_type:
        :param str i_part_number:
        :return: Product
        """
        return Product(self.products.AddNewComponent(i_documen_type, i_part_number))

    def add_new_product(self, i_part_number: str) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddNewProduct(CATBSTR iPartNumber) As Product
                | 
                |     Creates a Product reference object. This creates a Product reference object
                |     and the associated component by specifying its type and adds it to the Products
                |     collection.
                |
                |     Parameters:
                |
                |         iPartNumber
                |             The part number of the product to be created and added to the to
                |             the collection
                |
                |     Example:
                | 
                |           The following example creates the Engine product
                |          and adds the created component to the PowerTrains
                |          collection.
                |
                | 
                |          Dim Engine As Product
                |          Set Engine = PowerTrains.AddNewProduct(V6Engine)

        :param str i_part_number:
        :return: Product
        :rtype: Product
        """
        return Product(self.products.AddNewProduct(i_part_number))

    def item(self, i_index: cat_variant) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As Product
                | 
                |     Returns a product from its index in the Products
                |     collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the product to retrieve in the collection of products.
                |             This index can either be the rank of the product in the collection or the name
                |             you assign to the product. As a numerics, this index is the rank of the product
                |             in the collection. The index of the first product in the collection is 1, and
                |             the index of the last product is Count. As a string, it is the name you
                |             assigned to the product using the
                | 
                |         AnyObject.Name property
                |     Returns:
                |         The retrieved product
                |     Example:
                | 
                |           The following example returns in ThisProduct the third
                |           product,
                |          and in ThatProduct the product named
                |          Wheel in the CarParts product collection.
                |
                | 
                |          Dim ThisProduct As Product
                |          Set ThisProduct = CarParts.Item(3)
                |          Dim ThatProduct As Product
                |          Set ThatProduct = CarParts.Item("Wheel")

        :param cat_variant i_index:
        :return: Product
        :rtype: Product
        """
        return Product(self.products.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a product from the Products collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the product to remove. This index can either be the
                |             rank of the product in the collection or the name you assigned to the product.
                |             As a numerics, this index is the rank of the product in the collection. The
                |             index of the first product in the collection is 1, and the index of the last
                |             product is Count. As a string, it is the name you assigned to the product using
                |             the
                | 
                |         AnyObject.Name property
                |     Example:
                | 
                |           The following example removes the sixth product and the product
                |           named
                |          LeftRearDisc from the Brakes product collection.
                |
                | 
                |          Brakes.Remove(6)
                |          Brakes.Remove("LeftRearDisc")

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.products.Remove(i_index)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(products)
        # #     Dim iIndex (2)
        # #     products.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def replace_component(self, i_old_component: Product, i_file_path: str, i_multi_instances: bool) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func ReplaceComponent(Product iOldComponent,
                | CATBSTR iFilePath,
                | boolean iMultiInstances) As Product
                | 
                |     Creates a component which replace the given one.
                |
                |     Parameters:
                |
                |         iOldComponent
                |             The component which will be replaced
                |         iFilePath
                |             the document to replace with
                |         iMultiInstances
                |             Parameter to set to True if all instances are to be replaced, or to
                |             False otherwise. Returns the component replacing
                |             iOldComponent
                |
                |
                |             Note:
                |             Part Number conflict will be resolved
                |             automatically.

        :param Product i_old_component:
        :param str i_file_path:
        :param bool i_multi_instances:
        :return: Product
        :rtype: Product
        """
        return Product(self.products.ReplaceComponent(i_old_component.com_object, i_file_path, i_multi_instances))

    def replace_product(self, i_old_component: Product, i_new_reference: Product, i_multi_instances: bool) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func ReplaceProduct(Product iOldComponent,
                | Product iNewReference,
                | boolean iMultiInstances) As Product
                | 
                |     Creates a component which replace the given one.
                |
                |     Parameters:
                |
                |         iOldComponent
                |             The component which will be replaced
                |         iNewReference
                |             the reference whom the old copmponent will be reconnected
                |
                |         iMultiInstances
                |             Parameter to set to True if all instances are to be replaced, or to
                |             False otherwise. Returns the component replacing
                |             iOldComponent

        :param Product i_old_component:
        :param Product i_new_reference:
        :param bool i_multi_instances:
        :return: Product
        :rtype: Product
        """
        return Product(
            self.products.ReplaceProduct(
                i_old_component.com_object,
                i_new_reference.com_object,
                i_multi_instances
            )
        )

    def __len__(self):
        return self.count

    def __getitem__(self, n: int) -> Product:
        if (n + 1) > self.count:
            raise StopIteration

        return Product(self.products.item(n + 1))

    def __iter__(self) -> Iterator[Product]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Products(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.mec_mod_interfaces.body import Body
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Bodies(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Bodies
                |
                | A collection of all the Body objects contained in the part.

    """

    def __init__(self, collection_com_object):
        super().__init__(collection_com_object, child_object=Body)
        self.bodies = collection_com_object

    def add(self) -> Body:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add() As Body
                | 
                |     Creates a new body and adds it to the Bodies collection. This body becomes
                |     the current one
                | 
                |     Returns:
                |         The created body 
                |     Example:
                |         The following example creates a body names NewBody in the body
                |         collection of the rootPart part in the partDoc part document. NewBody becomes
                |         the current body in partDoc.
                | 
                |          Set rootPart = partDoc.Part
                |          Set NewBody = rootPart.Bodies.Add()

        :return: Body
        :rtype: Body
        """
        return Body(self.bodies.Add())

    def item(self, i_index: cat_variant) -> Body:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As Body
                | 
                |     Returns a body using its index or its name from the Bodies
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the body to retrieve from the collection
                |             of bodies. As a numerics, this index is the rank of the body in the collection.
                |             The index of the first body in the collection is 1, and the index of the last
                |             body is Count. As a string, it is the name you assigned to the body using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved body 
                |     Example:
                |         This example retrieves in ThisBody the fifth body in the collection and
                |         in ThatBody the body named MyBody in the body collection of the partDoc part
                |         document.
                | 
                |          Set BodyColl = partDoc.Part.Bodies
                |          Set ThisBody = BodyColl.Item(5)
                |          Set ThatBody = BodyColl.Item("MyBody")

        :param cat_variant i_index:
        :return: Body
        :rtype: Body
        """
        return Body(self.bodies.Item(i_index))

    def __getitem__(self, n: int) -> Body:
        if (n + 1) > self.count:
            raise StopIteration

        return Body(self.bodies.item(n + 1))

    def __iter__(self) -> Iterator[Body]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Bodies(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.sketcher_interfaces.geometric_element import GeometricElement
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class GeometricElements(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     GeometricElements
                | 
                | A collection of all geometric elements contained in a part or a
                | sketch.
                | Geometric elements are created with the 2D factory for the sketch and with the
                | 3D factory for the part. Geometric elements thus created are then aggregated
                | either in the sketch or as part of the geometric element
                | collection.
                | 
                | See also:
                |     Factory2D, HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=GeometricElement)
        self.geometric_elements = com_object

    def item(self, i_index: cat_variant) -> GeometricElement:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As GeometricElement
                | 
                |     Returns a geometric element using its index or its name from the
                |     GeometricElements collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the geometric element to retrieve from the
                |             collection of geometric elements. As a numerics, this index is the rank of the
                |             geometric element in the collection. The index of the first geometric element
                |             in the collection is 1, and the index of the last geometric element is Count.
                |             As a string, it is the name you assigned to the geometric element using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved geometric element 
                |     Example:
                |         This example retrieves the last item in the geometric element
                |         collection.
                | 
                |          Set lastCst = cstList.Item(cstList.Count)

        :param cat_variant i_index:
        :return: GeometricElement
        :rtype: GeometricElement
        """
        return GeometricElement(self.geometric_elements.Item(i_index))

    def __getitem__(self, n: int) -> GeometricElement:
        if (n + 1) > self.count:
            raise StopIteration

        return GeometricElement(self.geometric_elements.item(n + 1))

    def __iter__(self) -> Iterator[GeometricElement]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'GeometricElements(name="{self.name}")'
